@@ -1,6 +1,11 @@
 'use strict';
 import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
+import {NativeModules} from 'react-native';
+module.exports = NativeModules.DemoLibrary;
+
+import DemoLibrary from './DemoLibrary';
+
 
 var DemoLibrary = {
   checkEmail: function (email) {
@@ -24,6 +29,7 @@ var DemoLibrary = {
 
       }).then(response => response.text())
         .then((response) => {
+          console.log('local version ' , DemoLibrary.getPackageName())
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
           console.log('version ', version)
